==> customize-easy-ui-component-4.1.4.tgz: package/esm/stories/ScrollView.stories.js <==
/** @jsx jsx */
import { jsx } from "@emotion/core";
import { storiesOf } from "@storybook/react";
import { useState, useRef } from "react";
import { Pager } from "../Pager";
import { ScrollView } from "../ScrollView";
import * as React from "react";
import { Layer } from "../Layer";
import { Toolbar } from "../Toolbar";
import { Text } from "../Text";
import { Tabs, Tab } from "../Tabs";
import { List, ListItem } from "../List";
import { Avatar } from "../Avatar";
import { Badge } from "../Badge";
import * as faker from "faker";
export var ScrollViewStories = storiesOf("ScrollView", module)
    .add("within gesture", function () {
    return jsx(Example, null);
})
    .add("overflowY", function () { return jsx(Direction, null); })
    .add("animated scroll", function () { return jsx(AnimatedScroll, null); })
    .add("tabs example", function () { return jsx(TabsExample, null); });
function Example() {
    var _a = useState(0), index = _a[0], setIndex = _a[1];
    return (jsx("div", { css: { width: "200px" } },
        jsx(Pager, { css: { height: "400px " }, value: index, onRequestChange: function (i) { return setIndex(i); } },
            jsx("div", { css: { flex: 1, background: "green" } },
                jsx(ScrollView, { overflowX: true },
                    jsx("div", { css: { width: "300px", background: "yellow" } }, "this scrolls i guess expe Aute fugiat esse nulla enim esse reprehenderit do."))),
            jsx("div", { css: { flex: 1, background: "red" } }))));
}
function Direction() {
    var _a = useState(0), index = _a[0], setIndex = _a[1];
    return (jsx("div", { css: { width: "200px" } },
        jsx(Pager, { css: { height: "400px " }, value: index, onRequestChange: function (i) { return setIndex(i); } },
            jsx("div", { css: { flex: 1, background: "green" } },
                jsx(ScrollView, { overflowY: true, css: { height: "200px" } },
                    jsx("div", { css: { height: "400px", background: "yellow" } }, "this scrolls i guess expe Aute fugiat esse nulla enim esse reprehenderit do."))),
            jsx("div", { css: { flex: 1, background: "red" } }))));
}
function AnimatedScroll() {
    var ref = useRef(null);
    function scroll() {
        console.log(ref);
        ref.current.scrollTo(undefined, 400);
    }
    return (jsx(ScrollView, { css: { height: "300px" }, overflowY: true, innerRef: ref },
        jsx("div", { css: { height: "600px" } },
            "some scroll content",
            jsx("button", { onClick: scroll }, "scroll to 300")),
        jsx(React.Fragment, null,
            jsx("button", { onClick: function () { return ref.current.scrollTo(undefined, 0); } }, "scroll to 0"))));
}
function TabsExample() {
    var _a = useState(0), tab = _a[0], setTab = _a[1];
    return (jsx(Layer, { className: "List-example" },
        jsx(Toolbar, { className: "List-toolbar" },
            jsx(Text, { gutter: false, variant: "h6" }, "My Chat App")),
        jsx(Tabs, { variant: "evenly-spaced", onChange: function (i) { return setTab(i); }, value: tab },
            jsx(Tab, { id: "family" }, "Family"),
            jsx(Tab, { id: "work" }, "Work"),
            jsx(Tab, { id: "fav" }, "Favorites"),
            jsx(Tab, { id: "groups" }, "Groups")),
        jsx("div", null,
            jsx(List, null,
                jsx(ListItem, { contentBefore: jsx(Avatar, { name: "Lynn Apple", src: faker.image.avatar() }), primary: "Lynn Apple", wrap: false, secondary: "Proident irure cupidatat cupidatat elit eiusmod mollit.", contentAfter: jsx(Badge, null, "1") }),
                jsx(ListItem, { contentBefore: jsx(Avatar, { name: "Mary Joe", src: faker.image.avatar() }), primary: "Mary Joe", wrap: false, secondary: "Proident irure cupidatat cupidatat elit eiusmod mollit.", contentAfter: jsx(Badge, null, "4") })))));
}

==> customize-easy-ui-component-4.2.0.tgz: package/esm/stories/ScrollView.stories.js <==
/** @jsx jsx */
import { jsx } from "@emotion/core";
import { storiesOf } from "@storybook/react";
import { useState, useRef } from "react";
import { Pager } from "../Pager";
import { ScrollView } from "../ScrollView";
import * as React from "react";
import { Layer } from "../Layer";
import { Toolbar } from "../Toolbar";
import { Text } from "../Text";
import { Tabs, Tab } from "../Tabs";
import { List, ListItem } from "../List";
import { Avatar } from "../Avatar";
import { Badge } from "../Badge";
import * as faker from "faker";
export const ScrollViewStories = storiesOf("ScrollView", module)
    .add("within gesture", () => {
    return jsx(Example, null);
})
    .add("overflowY", () => jsx(Direction, null))
    .add("animated scroll", () => jsx(AnimatedScroll, null))
    .add("tabs example", () => jsx(TabsExample, null));
function Example() {
    const [index, setIndex] = useState(0);
    return (jsx("div", { css: { width: "200px" } },
        jsx(Pager, { css: { height: "400px " }, value: index, onRequestChange: i => setIndex(i) },
            jsx("div", { css: { flex: 1, background: "green" } },
                jsx(ScrollView, { overflowX: true },
                    jsx("div", { css: { width: "300px", background: "yellow" } }, "this scrolls i guess expe Aute fugiat esse nulla enim esse reprehenderit do."))),
            jsx("div", { css: { flex: 1, background: "red" } }))));
}
function Direction() {
    const [index, setIndex] = useState(0);
    return (jsx("div", { css: { width: "200px" } },
        jsx(Pager, { css: { height: "400px " }, value: index, onRequestChange: i => setIndex(i) },
            jsx("div", { css: { flex: 1, background: "green" } },
                jsx(ScrollView, { overflowY: true, css: { height: "200px" } },
                    jsx("div", { css: { height: "400px", background: "yellow" } }, "this scrolls i guess expe Aute fugiat esse nulla enim esse reprehenderit do."))),
            jsx("div", { css: { flex: 1, background: "red" } }))));
}
function AnimatedScroll() {
    const ref = useRef(null);
    function scroll() {
        console.log(ref);
        ref.current.scrollTo(undefined, 400);
    }
    return (jsx(ScrollView, { css: { height: "300px" }, overflowY: true, innerRef: ref },
        jsx("div", { css: { height: "600px" } },
            "some scroll content",
            jsx("button", { onClick: scroll }, "scroll to 300")),
        jsx(React.Fragment, null,
            jsx("button", { onClick: () => ref.current.scrollTo(undefined, 0) }, "scroll to 0"))));
}
function TabsExample() {
    const [tab, setTab] = useState(0);
    return (jsx(Layer, { className: "List-example" },
        jsx(Toolbar, { className: "List-toolbar" },
            jsx(Text, { gutter: false, variant: "h6" }, "My Chat App")),
        jsx(Tabs, { variant: "evenly-spaced", onChange: i => setTab(i), value: tab },
            jsx(Tab, { id: "family" }, "Family"),
            jsx(Tab, { id: "work" }, "Work"),
            jsx(Tab, { id: "fav" }, "Favorites"),
            jsx(Tab, { id: "groups" }, "Groups")),
        jsx("div", null,
            jsx(List, null,
                jsx(ListItem, { contentBefore: jsx(Avatar, { name: "Lynn Apple", src: faker.image.avatar() }), primary: "Lynn Apple", wrap: false, secondary: "Proident irure cupidatat cupidatat elit eiusmod mollit.", contentAfter: jsx(Badge, null, "1") }),
                jsx(ListItem, { contentBefore: jsx(Avatar, { name: "Mary Joe", src: faker.image.avatar() }), primary: "Mary Joe", wrap: false, secondary: "Proident irure cupidatat cupidatat elit eiusmod mollit.", contentAfter: jsx(Badge, null, "4") })))));
}
